@@ -1,5 +1,5 @@
 
-# $Id: Ebay.pm,v 2.258 2013-03-03 14:33:57 Martin Exp $
+# $Id: Ebay.pm,v 2.259 2013/03/17 01:01:06 martin Exp $
 
 =head1 NAME
 
@@ -100,23 +100,6 @@ you will get back one WWW::Search::Result without bid or price information.
 
 =over
 
-=item Search descriptions
-
-To search titles and descriptions, add 'srchdesc'=>'y' to the query options:
-
-  $oSearch->native_query($sQuery, { srchdesc => 'y' } );
-
-=item Search one category
-
-To restrict your search to a particular eBay category,
-find out eBay's ID number for the category and
-add 'sacategory'=>123 to the query options:
-
-  $oSearch->native_query($sQuery, { sacategory => 48995 } );
-
-If you send a single asterisk or a single space as the query string,
-the results will be ALL the auctions in that category.
-
 =item Limit search by price range
 
 Contributed by Brian Wilson:
@@ -156,7 +139,7 @@ use WWW::SearchResult 2.072;
 use WWW::Search::Result;
 
 our
-$VERSION = do { my @r = (q$Revision: 2.258 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
+$VERSION = do { my @r = (q$Revision: 2.259 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
 our $MAINTAINER = 'Martin Thurn <mthurn@cpan.org>';
 my $cgi = new CGI;
 
